﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Windows.Forms;

namespace FlexGrid_DataMap
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            c1FlexGrid1.DataSource = GetDummyData();
            c1FlexGrid1.Cols["DataMapCol"].DataMap = new Dictionary<int, string>()
            {
                {1, "z - first value" },
                {2, "x - second value" },
                {3, "y - third value" }
            };
            c1FlexGrid1.Cols["DataMapCol_Val"].Visible = false;
            c1FlexGrid1.AutoSizeCols();

            c1FlexGrid1.BeforeSort += C1FlexGrid1_BeforeSort;
        }

        private void C1FlexGrid1_BeforeSort(object sender, C1.Win.C1FlexGrid.SortColEventArgs e)
        {
            // use custom sorting for column "DataMapCol" (sort files by extension)
            if (c1FlexGrid1.Cols[e.Col].Name == "DataMapCol")
            {
                // handle the sort ourselves
                Cursor = Cursors.WaitCursor;

                c1FlexGrid1.Sort(e.Order, c1FlexGrid1.Cols["DataMapCol_Val"].Index);

                Cursor = null;

                // tell control we handled it
                e.Handled = true;
            }
        }

        DataTable GetDummyData()
        {
            return new DataTable()
            {
                Columns =
                {
                    new DataColumn("ID", typeof(int)),
                    new DataColumn("DataMapCol", typeof(int)),
                    new DataColumn("DataMapCol_Key", typeof(int)),
                    new DataColumn("DataMapCol_Val", typeof(string))
                },
                Rows =
                {
                    { 1, 1, 1, "z - first value"},
                    { 2, 1, 1, "z - first value"},
                    { 3, 2, 2, "x - second value"},
                    { 4, 3, 3, "y - third value"},
                    { 5, 2, 2, "x - second value"},
                    { 6, 1, 1, "z - first value"},
                }
            };
        }
    }

    public static class DataTableExtensions
    {
        public static DataTable ApplySort(this DataTable table, Comparison<DataRow> comparison)
        {

            DataTable clone = table.Clone();
            List<DataRow> rows = new List<DataRow>();
            foreach (DataRow row in table.Rows)
            {
                rows.Add(row);
            }

            rows.Sort(comparison);

            foreach (DataRow row in rows)
            {
                clone.Rows.Add(row.ItemArray);
            }

            return clone;
        }
    }
}
